@@ -6,12 +6,14 @@
 ##' listToDataFrame(a)
 ##' b = listToDataFrame(a)
 ##' @export
-listToDataFrame <- function (dlist) {
+listToDataFrame = function (dlist) {
   n = length(dlist)
   if (n>0) {
-    df = data.frame(dlist[1])
-    for (i in 2:n) {
-      df = rbind(df, dlist[[i]])
+    df = data.frame(dlist[[1]])
+    if (n>1) {
+      for (i in 2:n) {
+        df = rbind(df, dlist[[i]])
+      }
     }
   } else {
     stop("Enter with a non empty list")
